.. _exemple-wish-list-page:

===================
 Example Wish List
===================

Operational Points
------------------

* https://ahkab.readthedocs.io/en/latest/examples/Simple_OP.html
* DAC using resistor network
* Wheastone Bridge

Amplifier
---------

* AC Coupled Amplifier

Diode
-----

* Clampers
* Restaurateur de niveau moyen
* Detecteur d'enveloppe
* Redresseur sans seuil

Filters
-------

* Wien filter
* Tuinnenga p50 RLC
* RC / RL Bridge
* Butterworth
* High Frequence Probe (Delacressonnière p57)
* https://ahkab.readthedocs.io/en/latest/examples/PZ_Example.html

Inductors
----------

* https://ahkab.readthedocs.io/en/latest/help/Mutual-Inductors.html

Operational Amplifier
---------------------

* Integrator / Derivative
* Exponential / Logarithmic
* Current Source
* Astable
* Active filter
* Rauch
* Thermal Probe (Delacressonnière p43)
* Negative Impedance NIC (Delacressonnière p67)
* Peak-to-Peak Detector

Oscillators
-----------

* Colpitts Oscillator
  https://ahkab.readthedocs.io/en/latest/examples/Transient-Example.html
* Quartz oscillator

Power Supplies
--------------

* Zener Voltage Regulator

Switching Power Supplies
------------------------

Telecommunication
-----------------

* Simulate resistance using capacitive commutation (Delacressonnière p27)

Transistor
----------

* All configurations (Bolyestad p293)
* Cascode
* Darlington
* Feedback Pair
* Relay Driver
* Constant-Current Source
* Current Mirror
* Logic Gates
* Random Noise Generator (Bolyestad p329)

MOSFET
------

SCR
---

* Thyristor
* Diac
* Triac
* Zero Crossing Detector

.. End
